==> Mapster-1.6.6.zip: Mapster/Locale/frFR.lua <==
-- Mapster Locale
-- Please use the Localization App on WoWAce to Update this
-- http://www.wowace.com/projects/mapster/localization/ ;¶

local L = LibStub("AceLocale-3.0"):NewLocale("Mapster", "frFR")
if not L then return end

L["Accuracy"] = "Précision"
L["Adjust the size of the Player Arrow on the Map for better visibility."] = "Modifie la taille de la flèche du joueur sur la carte pour une meilleure visibilité."
L["Alpha"] = "Transparence"
L["BattleMap"] = "CarteLocale"
L["Change the scale of the world map if you do not want the whole screen filled while the map is open."] = "Modifiez l'échelle de la carte du monde si vous ne souhaitez pas que tout votre écran soit occupé quand la carte est ouverte."
L["Coordinates"] = "Coordonnées"
L["Cursor"] = "Curseur "
L["Disable Mouse"] = "Désactiver la souris"
L["Disable the mouse interactivity of the main map, eg. to change zones."] = "Désactive l'interactivité de la souris avec la carte principale évitant ainsi, par exemple, de changer de zone."
L["Disable the mouse interactivity of the main map when in minimized mode, eg. to change zones."] = "Désactive l'interactivité de la souris avec la carte principale minimisée évitant ainsi, par exemple, de changer de zone."
L["EJ Icon Scale"] = "Échelle icônes codex" -- Needs review
L["Enable BattleMap"] = "Activer CarteLocale"
L["Enable Coordinates"] = "Activer coordonnées"
L["Enable FogClear"] = "Activer antibrouillard"
L["Enable Group Icons"] = "Activer icônes de groupe"
L["Faded Alpha"] = "Transparence de fondu" -- Needs review
L["FogClear"] = "Antibrouillard"
L["Font Size"] = "Taille de la police" -- Needs review
L["Font Size on the minimized map."] = "Taille de la police sur la carte minimisée." -- Needs review
L["Font Size on the normal map."] = "Taille de la police sur la carte normale." -- Needs review
L["Group Icons"] = "Icônes de groupe"
L["Hide Border"] = "Cacher les bordures"
L["Hide Map Button"] = "Cacher le bouton de la carte"
L["Hide Textures"] = "Cacher les textures"
L["Hide the borders of the big map."] = "Cache les bordures de la grande carte."
L["Hide the borders of the minimized map."] = "Cache les bordures de la carte minimisée."
L["Hide the surrounding textures around the BattleMap, only leaving you with the pure map overlays."] = "Cache les textures entourant la CarteLocale, ne laissant que la carte en elle-même."
L["Mapster allows you to control various aspects of your World Map. You can change the style of the map, control the plugins that extend the map with new functionality, and configure different profiles for every of your characters."] = "Mapster vous permet de contrôler divers aspects de la carte du monde. Vous pouvez modifier son style, contrôler les plugins qui lui ajoutent de nouvelles fonctionnalités, et configurer différents profils pour tous vos personnages."
L["(Mini) Disable Mouse"] = "(Mini) Désactiver souris"
L["(Mini) Font Size"] = "(Mini) Taille de la police" -- Needs review
L["(Mini) Hide Border"] = "(Mini) Cacher bordures"
L["Minimized Alpha"] = "Transp. quand minimisée"
L["Minimized Scale"] = "Échelle quand minimisée"
L["Overlay Color"] = "Couleur de superposition"
L["Player"] = "Joueur "
L["PlayerArrow Scale"] = "Échelle flèche du joueur"
L["POI Scale"] = "Échelle des POIs"
L["Scale"] = "Échelle"
L["Scale of the big map."] = "Définit l'échelle de la grande carte."
L["Scale of the Encounter Journal Icons on the Map."] = "Échelle des icônes du codex des donjons sur la carte." -- Needs review
L["Scale of the minimized map."] = "Définit l'échelle de la carte minimisée."
L["Scale of the POI Icons on the Map."] = "Définit l'échelle des icônes des points d'intérêt sur la carte."
L["Size on the Battle Map"] = "Taille sur la carte de bataille"
L["Size on the World Map"] = "Taille sur la carte du monde"
L["The BattleMap module allows you to change the style of the BattlefieldMinimap, removing unnecessary textures or PvP Objectives."] = "Le module CarteLocale vous permet de changer le style de la carte locale (ou tactique) en enlevant les textures inutiles ou les objectifs JcJ."
L["The Coordinates module adds a display of your current location, and the coordinates of your mouse cursor to the World Map frame."] = "Le module des coordonnées ajoute sur la fenêtre de la carte du monde les coordonnées actuelles de votre personnage ainsi que ceux de votre curseur."
L["The FogClear module removes the Fog of War from the World map, thus displaying the artwork for all the undiscovered zones, optionally with a color overlay on undiscovered areas."] = "Le module d'antibrouillard enlève le brouillard de guerre de la carte du monde, affichant ainsi tout ce qui se trouve dans les zones qui vous sont inconnues."
L["The Group Icons module allows you to resize the raid and party icons on the world map."] = "Le module Icônes de groupe vous permet de redimensionner les icônes du groupe et du raid de la carte du monde."
L["The map will fade out to the configured Fade Alpha level when you start moving."] = "La carte s'estompera au niveau de transparence de fondu configuré quand vous commencez à vous déplacer." -- Needs review
L["The transparency of the big map."] = "Définit la transparence de la grande carte."
L["The transparency of the map while you are moving and the map is faded."] = "La transparence de la carte quand vous vous déplacez et que la carte est estompée." -- Needs review
L["The transparency of the minimized map."] = "Définit la transparence de la carte minimisée."
L["You can change the transparency of the world map to allow you to continue seeing the world environment while your map is open for navigation."] = "Vous pouvez modifier la transparence de la carte du monde afin de continuer à voir l'environnement du jeu quand vous consultez la carte."
L["You can control the accuracy of the coordinates, e.g. if you need very exact coordinates you can set this to 2."] = "Vous pouvez ici déterminer la précision des coordonnées. Par exemple, si vous voulez des coordonnées très précises, mettez la valeur à 2."

==> Mapster-1.7.6.zip: Mapster/Locale/frFR.lua <==
-- Mapster Locale
-- Please use the Localization App on WoWAce to Update this
-- http://www.wowace.com/projects/mapster/localization/ ;¶

local L = LibStub("AceLocale-3.0"):NewLocale("Mapster", "frFR")
if not L then return end

L["Accuracy"] = "Précision"
L["Adjust the size of the Player Arrow on the Map for better visibility."] = "Modifie la taille de la flèche du joueur sur la carte pour une meilleure visibilité."
L["Alpha"] = "Transparence"
L["BattleMap"] = "CarteLocale"
L["Change the scale of the world map if you do not want the whole screen filled while the map is open."] = "Modifiez l'échelle de la carte du monde si vous ne souhaitez pas que tout votre écran soit occupé quand la carte est ouverte."
L["Coordinates"] = "Coordonnées"
L["Cursor"] = "Curseur "
L["Disable Mouse"] = "Désactiver la souris"
L["Disable the mouse interactivity of the main map, eg. to change zones."] = "Désactive l'interactivité de la souris avec la carte principale évitant ainsi, par exemple, de changer de zone."
L["EJ Icon Scale"] = "Échelle icônes codex"
L["Enable BattleMap"] = "Activer CarteLocale"
L["Enable Coordinates"] = "Activer coordonnées"
L["Enable FogClear"] = "Activer antibrouillard"
L["Enable Group Icons"] = "Activer icônes de groupe"
L["Faded Alpha"] = "Transparence de fondu"
L["FogClear"] = "Antibrouillard"
L["Font Size"] = "Taille de la police"
L["Font Size on the normal map."] = "Taille de la police sur la carte normale."
L["Group Icons"] = "Icônes de groupe"
L["Hide Map Button"] = "Cacher le bouton de la carte"
L["Hide Textures"] = "Cacher les textures"
L["Hide the surrounding textures around the BattleMap, only leaving you with the pure map overlays."] = "Cache les textures entourant la CarteLocale, ne laissant que la carte en elle-même."
L["Mapster allows you to control various aspects of your World Map. You can change the style of the map, control the plugins that extend the map with new functionality, and configure different profiles for every of your characters."] = "Mapster vous permet de contrôler divers aspects de la carte du monde. Vous pouvez modifier son style, contrôler les plugins qui lui ajoutent de nouvelles fonctionnalités, et configurer différents profils pour tous vos personnages."
L["Overlay Color"] = "Couleur de superposition"
L["Player"] = "Joueur "
L["PlayerArrow Scale"] = "Échelle flèche du joueur"
L["POI Scale"] = "Échelle des POIs"
L["Scale"] = "Échelle"
L["Scale of the big map."] = "Définit l'échelle de la grande carte."
L["Scale of the Encounter Journal Icons on the Map."] = "Échelle des icônes du codex des donjons sur la carte."
L["Scale of the POI Icons on the Map."] = "Définit l'échelle des icônes des points d'intérêt sur la carte."
L["Size on the Battle Map"] = "Taille sur la carte de bataille"
L["Size on the World Map"] = "Taille sur la carte du monde"
L["The BattleMap module allows you to change the style of the BattlefieldMinimap, removing unnecessary textures or PvP Objectives."] = "Le module CarteLocale vous permet de changer le style de la carte locale (ou tactique) en enlevant les textures inutiles ou les objectifs JcJ."
L["The Coordinates module adds a display of your current location, and the coordinates of your mouse cursor to the World Map frame."] = "Le module des coordonnées ajoute sur la fenêtre de la carte du monde les coordonnées actuelles de votre personnage ainsi que ceux de votre curseur."
L["The FogClear module removes the Fog of War from the World map, thus displaying the artwork for all the undiscovered zones, optionally with a color overlay on undiscovered areas."] = "Le module d'antibrouillard enlève le brouillard de guerre de la carte du monde, affichant ainsi tout ce qui se trouve dans les zones qui vous sont inconnues."
L["The Group Icons module allows you to resize the raid and party icons on the world map."] = "Le module Icônes de groupe vous permet de redimensionner les icônes du groupe et du raid de la carte du monde."
L["The map will fade out to the configured Fade Alpha level when you start moving."] = "La carte s'estompera au niveau de transparence de fondu configuré quand vous commencez à vous déplacer."
L["The transparency of the big map."] = "Définit la transparence de la grande carte."
L["The transparency of the map while you are moving and the map is faded."] = "La transparence de la carte quand vous vous déplacez et que la carte est estompée."
L["You can change the transparency of the world map to allow you to continue seeing the world environment while your map is open for navigation."] = "Vous pouvez modifier la transparence de la carte du monde afin de continuer à voir l'environnement du jeu quand vous consultez la carte."
L["You can control the accuracy of the coordinates, e.g. if you need very exact coordinates you can set this to 2."] = "Vous pouvez ici déterminer la précision des coordonnées. Par exemple, si vous voulez des coordonnées très précises, mettez la valeur à 2."
